[![Release Build](https://github.com/emetriq/pytargetingutilities/actions/workflows/release.yaml/badge.svg)](https://github.com/emetriq/pytargetingutilities/actions/workflows/release.yaml)
[![Coverage Status](https://coveralls.io/repos/github/emetriq/pytargetingutilities/badge.svg?branch=main)](https://coveralls.io/github/emetriq/pytargetingutilities?branch=main)
# pytargetingutilities

AWS boilerplate code for python applications.

## install

Install latest package
`pip install pytargetingutilities`

Copy latest package to workspace:
`pip download --no-deps pytargetingutilities`

